spannertools.report_as_string_format_contributions_of_all_spanners_attached_to_improper_parentage_of_component
==============================================================================================================

.. autofunction:: abjad.tools.spannertools.report_as_string_format_contributions_of_all_spanners_attached_to_improper_parentage_of_component.report_as_string_format_contributions_of_all_spanners_attached_to_improper_parentage_of_component
